@@ -1,4 +1,4 @@
-# $Id: install.py 1792 2019-01-10 13:20:43Z mwall $
+# $Id: install.py 1795 2019-02-05 22:16:31Z mwall $
 # installer for the forecast extension
 # Copyright 2014-2016 Matthew Wall
 
@@ -10,7 +10,7 @@ def loader():
 class ForecastInstaller(ExtensionInstaller):
     def __init__(self):
         super(ForecastInstaller, self).__init__(
-            version="3.3.0",
+            version="3.3.1",
             name='forecast',
             description='Generate and display weather and tide forecasts.',
             author="Matthew Wall",
@@ -45,9 +45,9 @@ class ForecastInstaller(ExtensionInstaller):
                         'client_id': 'INSERT_AERIS_CLIENT_ID_HERE',
                         'client_secret': 'INSERT_AERIS_CLIENT_SECRET_HERE'},
                     'WWO': {
-                        'api_key': 'INSERT_WWO_API_KEY_HERE'}},
+                        'api_key': 'INSERT_WWO_API_KEY_HERE'},
                     'DS': {
-                        'api_key': 'INSERT_DS_API_KEY_HERE'},
+                        'api_key': 'INSERT_DS_API_KEY_HERE'}},
                 'DataBindings': {
                     'forecast_binding': {
                         'database': 'forecast_sqlite'}},
